@@ -7,7 +7,7 @@ from typing import Optional
 import click
 
 from .api_client import StudioManagerClient
-from .auth import get_aws_username, check_aws_auth, detect_aws_environment
+from .auth import check_aws_auth, detect_aws_environment, get_aws_username
 from .progress import format_idle_state, format_time_ago, wait_with_progress
 
 
@@ -118,7 +118,11 @@ def engine_cli():
 @click.option(
     "--skip-ssh-config", is_flag=True, help="Don't automatically update SSH config"
 )
-@click.option("--env", default=None, help="Environment (dev, sand, prod) - auto-detected if not specified")
+@click.option(
+    "--env",
+    default=None,
+    help="Environment (dev, sand, prod) - auto-detected if not specified",
+)
 def launch_engine(
     name: str,
     engine_type: str,
@@ -131,15 +135,17 @@ def launch_engine(
 
     # Check AWS auth first to provide clear error messages
     check_aws_auth()
-    
+
     # Auto-detect environment if not specified
     if env is None:
         env = detect_aws_environment()
         click.echo(f"🔍 Detected environment: {env}")
-        
+
         # Require confirmation for non-dev environments
         if env != "dev":
-            if not click.confirm(f"⚠️  You are about to launch in {env.upper()}. Continue?"):
+            if not click.confirm(
+                f"⚠️  You are about to launch in {env.upper()}. Continue?"
+            ):
                 click.echo("Cancelled")
                 raise click.Abort()
 
@@ -206,21 +212,29 @@ def launch_engine(
 @click.option(
     "--skip-ssh-config", is_flag=True, help="Don't automatically update SSH config"
 )
-@click.option("--env", default=None, help="Environment (dev, sand, prod) - auto-detected if not specified")
-def start_engine(name_or_id: str, no_wait: bool, skip_ssh_config: bool, env: Optional[str]):
+@click.option(
+    "--env",
+    default=None,
+    help="Environment (dev, sand, prod) - auto-detected if not specified",
+)
+def start_engine(
+    name_or_id: str, no_wait: bool, skip_ssh_config: bool, env: Optional[str]
+):
     """Start a stopped engine."""
 
     # Check AWS auth first to provide clear error messages
     check_aws_auth()
-    
+
     # Auto-detect environment if not specified
     if env is None:
         env = detect_aws_environment()
         click.echo(f"🔍 Detected environment: {env}")
-        
+
         # Require confirmation for non-dev environments
         if env != "dev":
-            if not click.confirm(f"⚠️  You are about to operate in {env.upper()}. Continue?"):
+            if not click.confirm(
+                f"⚠️  You are about to operate in {env.upper()}. Continue?"
+            ):
                 click.echo("Cancelled")
                 raise click.Abort()
 
@@ -320,21 +334,27 @@ def start_engine(name_or_id: str, no_wait: bool, skip_ssh_config: bool, env: Opt
 
 @engine_cli.command("stop")
 @click.argument("name_or_id")
-@click.option("--env", default=None, help="Environment (dev, sand, prod) - auto-detected if not specified")
+@click.option(
+    "--env",
+    default=None,
+    help="Environment (dev, sand, prod) - auto-detected if not specified",
+)
 def stop_engine(name_or_id: str, env: Optional[str]):
     """Stop a running engine."""
 
     # Check AWS auth first to provide clear error messages
     check_aws_auth()
-    
+
     # Auto-detect environment if not specified
     if env is None:
         env = detect_aws_environment()
         click.echo(f"🔍 Detected environment: {env}")
-        
+
         # Require confirmation for non-dev environments
         if env != "dev":
-            if not click.confirm(f"⚠️  You are about to operate in {env.upper()}. Continue?"):
+            if not click.confirm(
+                f"⚠️  You are about to operate in {env.upper()}. Continue?"
+            ):
                 click.echo("Cancelled")
                 raise click.Abort()
 
@@ -367,21 +387,27 @@ def stop_engine(name_or_id: str, env: Optional[str]):
 @engine_cli.command("terminate")
 @click.argument("name_or_id")
 @click.option("--yes", "-y", is_flag=True, help="Skip confirmation")
-@click.option("--env", default=None, help="Environment (dev, sand, prod) - auto-detected if not specified")
+@click.option(
+    "--env",
+    default=None,
+    help="Environment (dev, sand, prod) - auto-detected if not specified",
+)
 def terminate_engine(name_or_id: str, yes: bool, env: Optional[str]):
     """Terminate an engine."""
 
     # Check AWS auth first to provide clear error messages
     check_aws_auth()
-    
+
     # Auto-detect environment if not specified
     if env is None:
         env = detect_aws_environment()
         click.echo(f"🔍 Detected environment: {env}")
-        
+
         # Require confirmation for non-dev environments
         if env != "dev":
-            if not click.confirm(f"⚠️  You are about to operate in {env.upper()}. Continue?"):
+            if not click.confirm(
+                f"⚠️  You are about to operate in {env.upper()}. Continue?"
+            ):
                 click.echo("Cancelled")
                 raise click.Abort()
 
@@ -423,13 +449,17 @@ def terminate_engine(name_or_id: str, yes: bool, env: Optional[str]):
 
 @engine_cli.command("status")
 @click.argument("name_or_id")
-@click.option("--env", default=None, help="Environment (dev, sand, prod) - auto-detected if not specified")
+@click.option(
+    "--env",
+    default=None,
+    help="Environment (dev, sand, prod) - auto-detected if not specified",
+)
 def engine_status(name_or_id: str, env: Optional[str]):
     """Show engine status including idle detector state."""
 
     # Check AWS auth first to provide clear error messages
     check_aws_auth()
-    
+
     # Auto-detect environment if not specified
     if env is None:
         env = detect_aws_environment()
@@ -454,18 +484,29 @@ def engine_status(name_or_id: str, env: Optional[str]):
 
         # Display basic info - reordered per user request
         engine_name = status_data.get("name", engine_id)
-        click.echo(f"Name: \033[34m{engine_name}\033[0m")  # Blue engine name (renamed from "Engine")
-        
-        # Show state in red if stopped, normal otherwise
+        click.echo(
+            f"Name: \033[34m{engine_name}\033[0m"
+        )  # Blue engine name (renamed from "Engine")
+
+        # Show state with color coding
         engine_state = status_data.get("state", "unknown")
-        if engine_state.lower() in ["stopped", "stopping", "terminated", "terminating"]:
-            click.echo(f"State: \033[31m{engine_state}\033[0m")  # Red for stopped
+        state_lower = engine_state.lower()
+        if state_lower == "running":
+            click.echo(f"State: \033[32m{engine_state}\033[0m")  # Green for running
+        elif state_lower in ["stopped", "terminated"]:
+            click.echo(
+                f"State: \033[31m{engine_state}\033[0m"
+            )  # Red for stopped/terminated
+        elif state_lower in ["stopping", "starting", "pending"]:
+            click.echo(
+                f"State: \033[33m{engine_state}\033[0m"
+            )  # Yellow for transitional states
         else:
-            click.echo(f"State: {engine_state}")
+            click.echo(f"State: {engine_state}")  # No color for unknown states
 
         if status_data.get("launch_time"):
             click.echo(f"Launched: {format_time_ago(status_data['launch_time'])}")
-        
+
         click.echo(f"Type: {status_data.get('instance_type', 'unknown')}")
         click.echo(f"Instance ID: {engine_id}")
 
@@ -503,13 +544,17 @@ def engine_status(name_or_id: str, env: Optional[str]):
 
 
 @engine_cli.command("list")
-@click.option("--env", default=None, help="Environment (dev, sand, prod) - auto-detected if not specified")
+@click.option(
+    "--env",
+    default=None,
+    help="Environment (dev, sand, prod) - auto-detected if not specified",
+)
 def list_engines(env: Optional[str]):
     """List all engines."""
 
     # Check AWS auth first to provide clear error messages
     check_aws_auth()
-    
+
     # Auto-detect environment if not specified
     if env is None:
         env = detect_aws_environment()
@@ -525,18 +570,22 @@ def list_engines(env: Optional[str]):
             return
 
         # Table header - reordered per user request: Name, State, User, Type, Instance ID
-        click.echo(f"{'Name':<30} {'State':<10} {'User':<15} {'Type':<15} {'Instance ID':<20}")
-        click.echo("-" * 95)
+        click.echo(
+            f"{'Name':<12} {'State':<12} {'User':<12} {'Type':<12} {'Instance ID':<20}"
+        )
+        click.echo("-" * 72)
 
         # Table rows
         for engine in engines:
-            name = engine.get("name", "unknown")[:29]
-            state = engine.get("state", "unknown")
-            user = engine.get("user", "unknown")[:14]
-            engine_type = engine.get("engine_type", "unknown")
+            name = engine.get("name", "unknown")[:11]
+            state = engine.get("state", "unknown")[:11]
+            user = engine.get("user", "unknown")[:11]
+            engine_type = engine.get("engine_type", "unknown")[:11]
             instance_id = engine.get("instance_id", "unknown")
 
-            click.echo(f"{name:<30} {state:<10} {user:<15} {engine_type:<15} {instance_id:<20}")
+            click.echo(
+                f"{name:<12} {state:<12} {user:<12} {engine_type:<12} {instance_id:<20}"
+            )
 
         click.echo(f"\nTotal: {len(engines)} engine(s)")
 
@@ -558,16 +607,22 @@ def list_engines(env: Optional[str]):
     is_flag=True,
     help="Generate entries using ec2-user instead of owner",
 )
-@click.option("--env", default=None, help="Environment (dev, sand, prod) - auto-detected if not specified")
+@click.option(
+    "--env",
+    default=None,
+    help="Environment (dev, sand, prod) - auto-detected if not specified",
+)
 def config_ssh(clean: bool, all: bool, admin: bool, env: Optional[str]):
     """Update SSH config with available engines."""
-    
+
     # Auto-detect environment if not specified (and not just cleaning)
     if env is None and not clean:
         check_aws_auth()
         env = detect_aws_environment()
+    elif env is None:
+        env = "dev"  # Default for clean operation
 
-    client = StudioManagerClient(environment=env if env else "dev")
+    client = StudioManagerClient(environment=env)
     ssh_config_path = os.path.expanduser("~/.ssh/config")
 
     try:
@@ -673,13 +728,17 @@ def config_ssh(clean: bool, all: bool, admin: bool, env: Optional[str]):
 @click.argument("name_or_id")
 @click.argument("duration", required=False)
 @click.option("--cancel", is_flag=True, help="Cancel existing coffee lock")
-@click.option("--env", default=None, help="Environment (dev, sand, prod) - auto-detected if not specified")
+@click.option(
+    "--env",
+    default=None,
+    help="Environment (dev, sand, prod) - auto-detected if not specified",
+)
 def coffee(name_or_id: str, duration: Optional[str], cancel: bool, env: Optional[str]):
     """Keep engine awake for specified duration (e.g., '4h', '2h30m')."""
-    
+
     # Check AWS auth and auto-detect environment if not specified
     check_aws_auth()
-    
+
     if env is None:
         env = detect_aws_environment()
 
@@ -724,15 +783,22 @@ def coffee(name_or_id: str, duration: Optional[str], cancel: bool, env: Optional
     type=click.Choice(["none", "default", "all"]),
     help="Set Slack notifications",
 )
-@click.option("--env", default=None, help="Environment (dev, sand, prod) - auto-detected if not specified")
+@click.option(
+    "--env",
+    default=None,
+    help="Environment (dev, sand, prod) - auto-detected if not specified",
+)
 def idle_timeout_cmd(
-    name_or_id: str, set_timeout: Optional[str], slack: Optional[str], env: Optional[str]
+    name_or_id: str,
+    set_timeout: Optional[str],
+    slack: Optional[str],
+    env: Optional[str],
 ):
     """Show or configure idle detector settings."""
-    
+
     # Check AWS auth and auto-detect environment if not specified
     check_aws_auth()
-    
+
     if env is None:
         env = detect_aws_environment()
 
@@ -794,13 +860,19 @@ def idle_timeout_cmd(
     help="Resize while running (requires manual filesystem expansion)",
 )
 @click.option("--force", "-f", is_flag=True, help="Force resize")
-@click.option("--env", default=None, help="Environment (dev, sand, prod) - auto-detected if not specified")
-def resize_engine(name_or_id: str, size: int, online: bool, force: bool, env: Optional[str]):
+@click.option(
+    "--env",
+    default=None,
+    help="Environment (dev, sand, prod) - auto-detected if not specified",
+)
+def resize_engine(
+    name_or_id: str, size: int, online: bool, force: bool, env: Optional[str]
+):
     """Resize an engine's boot disk."""
-    
+
     # Check AWS auth and auto-detect environment if not specified
     check_aws_auth()
-    
+
     if env is None:
         env = detect_aws_environment()
 
@@ -837,13 +909,17 @@ def resize_engine(name_or_id: str, size: int, online: bool, force: bool, env: Op
 
 @engine_cli.command("gami")
 @click.argument("name_or_id")
-@click.option("--env", default=None, help="Environment (dev, sand, prod) - auto-detected if not specified")
+@click.option(
+    "--env",
+    default=None,
+    help="Environment (dev, sand, prod) - auto-detected if not specified",
+)
 def create_ami(name_or_id: str, env: Optional[str]):
     """Create a Golden AMI from an engine."""
-    
+
     # Check AWS auth and auto-detect environment if not specified
     check_aws_auth()
-    
+
     if env is None:
         env = detect_aws_environment()
 
@@ -877,13 +953,17 @@ def create_ami(name_or_id: str, env: Optional[str]):
 
 @engine_cli.command("debug")
 @click.argument("name_or_id")
-@click.option("--env", default=None, help="Environment (dev, sand, prod) - auto-detected if not specified")
+@click.option(
+    "--env",
+    default=None,
+    help="Environment (dev, sand, prod) - auto-detected if not specified",
+)
 def debug_engine(name_or_id: str, env: Optional[str]):
     """Debug engine bootstrap status and files."""
-    
+
     # Check AWS auth and auto-detect environment if not specified
     check_aws_auth()
-    
+
     if env is None:
         env = detect_aws_environment()
 
