@@ -161,30 +161,45 @@ def format_idle_state(
         for sensor_name, sensor_data in idle_state["sensors"].items():
             emoji = sensor_emojis.get(sensor_name.lower(), "📊")
             active = sensor_data.get("active", False)
-            status_icon = format_sensor_status(sensor_data)
-
-            # Format: emoji NAME status_icon (on same line for inactive, split for active)
-            if active:
-                lines.append(
-                    f"\n{emoji} {sensor_name.upper()} {status_icon.split(chr(10))[0]}"
-                )
-                # Add reason on next line
-                reason_line = status_icon.split("\n")[1] if "\n" in status_icon else ""
-                if reason_line:
-                    lines.append(reason_line)
+            
+            # Special formatting for coffee sensor
+            if sensor_name.lower() == "coffee" and active:
+                # Extract minutes from details for cleaner display
+                details = sensor_data.get("details", {})
+                remaining_seconds = details.get("remaining_seconds", 0)
+                remaining_minutes = remaining_seconds // 60
+                lines.append(f"\n{emoji} {sensor_name.upper()} 🟢")
+                lines.append(f"  Caffeinated for another {remaining_minutes}m")
             else:
-                lines.append(f"\n{emoji} {sensor_name.upper()} {status_icon}")
+                status_icon = format_sensor_status(sensor_data)
+                # Format: emoji NAME status_icon (on same line for inactive, split for active)
+                if active:
+                    lines.append(
+                        f"\n{emoji} {sensor_name.upper()} {status_icon.split(chr(10))[0]}"
+                    )
+                    # Add reason on next line
+                    reason_line = status_icon.split("\n")[1] if "\n" in status_icon else ""
+                    if reason_line:
+                        lines.append(reason_line)
+                else:
+                    lines.append(f"\n{emoji} {sensor_name.upper()} {status_icon}")
 
-            # Show details if available
+            # Show details if available (skip for active coffee sensor with special formatting)
+            if sensor_name.lower() == "coffee" and active:
+                continue  # Already showed coffee details in special format above
+            
             details = sensor_data.get("details", {})
             if details:
                 for key, value in details.items():
-                    # Skip internal bookkeeping fields
+                    # Skip internal bookkeeping fields and redundant info
                     if key in [
                         "unique_flavor_count",
                         "unique_pid_count",
                         "expires_at",
                         "flavors",
+                        "remaining_seconds",  # Redundant with time shown in reason
+                        "pid_count",  # Redundant with connections list
+                        "connections",  # Redundant, connections shown in sessions/containers
                     ]:
                         continue
 
