@@ -6,7 +6,7 @@ from typing import Optional
 import click
 
 from .api_client import StudioManagerClient
-from .auth import get_aws_username
+from .auth import check_aws_auth, get_aws_username, detect_aws_environment
 from .progress import format_time_ago, wait_with_progress
 
 
@@ -23,12 +23,26 @@ def studio_cli():
 
 @studio_cli.command("create")
 @click.option("--size", "size_gb", type=int, default=100, help="Studio size in GB")
-@click.option("--env", default="dev", help="Environment (dev, sand, prod)")
-def create_studio(size_gb: int, env: str):
+@click.option("--env", default=None, help="Environment (dev, sand, prod) - auto-detected if not specified")
+def create_studio(size_gb: int, env: Optional[str]):
     """Create a new studio for the current user."""
 
-    client = StudioManagerClient(environment=env)
+    # Check AWS auth first to provide clear error messages
+    check_aws_auth()
     
+    # Auto-detect environment if not specified
+    if env is None:
+        env = detect_aws_environment()
+        click.echo(f"🔍 Detected environment: {env}")
+        
+        # Require confirmation for non-dev environments
+        if env != "dev":
+            if not click.confirm(f"⚠️  You are about to create in {env.upper()}. Continue?"):
+                click.echo("Cancelled")
+                raise click.Abort()
+
+    client = StudioManagerClient(environment=env)
+
     try:
         user = get_aws_username()
     except RuntimeError as e:
@@ -65,10 +79,17 @@ def create_studio(size_gb: int, env: str):
 
 @studio_cli.command("delete")
 @click.option("--yes", "-y", is_flag=True, help="Skip confirmation")
-@click.option("--env", default="dev", help="Environment (dev, sand, prod)")
-def delete_studio(yes: bool, env: str):
+@click.option("--env", default=None, help="Environment (dev, sand, prod) - auto-detected if not specified")
+def delete_studio(yes: bool, env: Optional[str]):
     """Delete your studio (WARNING: This deletes all data!)."""
 
+    # Check AWS auth first to provide clear error messages
+    check_aws_auth()
+    
+    # Auto-detect environment if not specified
+    if env is None:
+        env = detect_aws_environment()
+
     client = StudioManagerClient(environment=env)
 
     try:
@@ -115,10 +136,17 @@ def delete_studio(yes: bool, env: str):
 
 
 @studio_cli.command("status")
-@click.option("--env", default="dev", help="Environment (dev, sand, prod)")
-def studio_status(env: str):
+@click.option("--env", default=None, help="Environment (dev, sand, prod) - auto-detected if not specified")
+def studio_status(env: Optional[str]):
     """Show information about your studio."""
 
+    # Check AWS auth first to provide clear error messages
+    check_aws_auth()
+    
+    # Auto-detect environment if not specified
+    if env is None:
+        env = detect_aws_environment()
+
     client = StudioManagerClient(environment=env)
 
     try:
@@ -132,10 +160,11 @@ def studio_status(env: str):
         click.echo(f"User: {studio['user']}")
         click.echo(f"Size: {studio['size_gb']}GB")
         click.echo(f"Status: {studio['status']}")
-        click.echo(f"Created: {format_time_ago(studio['creation_date'])}")
+        if studio.get('created_at'):
+            click.echo(f"Created: {format_time_ago(studio['created_at'])}")
 
-        if studio.get("attached_engine_id"):
-            click.echo(f"Attached to: {studio['attached_engine_id']}")
+        if studio.get("attached_to"):
+            click.echo(f"Attached to: {studio['attached_to']}")
 
     except Exception as e:
         click.echo(f"✗ Error: {e}", err=True)
@@ -143,10 +172,17 @@ def studio_status(env: str):
 
 
 @studio_cli.command("list")
-@click.option("--env", default="dev", help="Environment (dev, sand, prod)")
-def list_studios(env: str):
+@click.option("--env", default=None, help="Environment (dev, sand, prod) - auto-detected if not specified")
+def list_studios(env: Optional[str]):
     """List all studios."""
 
+    # Check AWS auth first to provide clear error messages
+    check_aws_auth()
+    
+    # Auto-detect environment if not specified
+    if env is None:
+        env = detect_aws_environment()
+
     client = StudioManagerClient(environment=env)
 
     try:
@@ -184,10 +220,17 @@ def list_studios(env: str):
 
 @studio_cli.command("attach")
 @click.argument("engine_name_or_id")
-@click.option("--env", default="dev", help="Environment (dev, sand, prod)")
-def attach_studio(engine_name_or_id: str, env: str):
+@click.option("--env", default=None, help="Environment (dev, sand, prod) - auto-detected if not specified")
+def attach_studio(engine_name_or_id: str, env: Optional[str]):
     """Attach your studio to an engine with progress tracking."""
 
+    # Check AWS auth first to provide clear error messages
+    check_aws_auth()
+    
+    # Auto-detect environment if not specified
+    if env is None:
+        env = detect_aws_environment()
+
     client = StudioManagerClient(environment=env)
 
     try:
@@ -279,10 +322,17 @@ def attach_studio(engine_name_or_id: str, env: str):
 
 
 @studio_cli.command("detach")
-@click.option("--env", default="dev", help="Environment (dev, sand, prod)")
-def detach_studio(env: str):
+@click.option("--env", default=None, help="Environment (dev, sand, prod) - auto-detected if not specified")
+def detach_studio(env: Optional[str]):
     """Detach your studio from its engine."""
 
+    # Check AWS auth first to provide clear error messages
+    check_aws_auth()
+    
+    # Auto-detect environment if not specified
+    if env is None:
+        env = detect_aws_environment()
+
     client = StudioManagerClient(environment=env)
 
     try:
@@ -322,9 +372,15 @@ def detach_studio(env: str):
 
 @studio_cli.command("resize")
 @click.option("--size", "-s", required=True, type=int, help="New size in GB")
-@click.option("--env", default="dev", help="Environment (dev, sand, prod)")
-def resize_studio(size: int, env: str):
+@click.option("--env", default=None, help="Environment (dev, sand, prod) - auto-detected if not specified")
+def resize_studio(size: int, env: Optional[str]):
     """Resize your studio volume (requires detachment)."""
+    
+    # Check AWS auth and auto-detect environment if not specified
+    check_aws_auth()
+    
+    if env is None:
+        env = detect_aws_environment()
 
     client = StudioManagerClient(environment=env)
 
@@ -346,7 +402,7 @@ def resize_studio(size: int, env: str):
             raise click.Abort()
 
         current_size = studio.get("size_gb", 0)
-        
+
         if size <= current_size:
             click.echo(
                 f"✗ New size ({size}GB) must be larger than current size ({current_size}GB)",
@@ -372,9 +428,15 @@ def resize_studio(size: int, env: str):
 
 
 @studio_cli.command("reset")
-@click.option("--env", default="dev", help="Environment (dev, sand, prod)")
-def reset_studio(env: str):
+@click.option("--env", default=None, help="Environment (dev, sand, prod) - auto-detected if not specified")
+def reset_studio(env: Optional[str]):
     """Reset a stuck studio (admin operation)."""
+    
+    # Check AWS auth and auto-detect environment if not specified
+    check_aws_auth()
+    
+    if env is None:
+        env = detect_aws_environment()
 
     client = StudioManagerClient(environment=env)
 
@@ -411,4 +473,3 @@ def reset_studio(env: str):
     except Exception as e:
         click.echo(f"✗ Error: {e}", err=True)
         raise click.Abort()
-
