@@ -477,10 +477,21 @@ def submit_aws_batch_job(
     print(f"Setting retry attempts to {retry_attempts}")
     job_submit_args["retryStrategy"] = {"attempts": retry_attempts}
 
-    # Add tags if specified in config
+    # Automatically add User tag for cost tracking
+    username = os.getenv("LOCAL_USER", "unknown_user")
+    default_tags = {"User": username}
+
+    # Merge with any tags specified in config (config tags take precedence)
     if "tags" in aws_config:
-        job_submit_args["tags"] = aws_config["tags"]
-        print(f"Adding tags to batch job: {aws_config['tags']}")
+        tags = {**default_tags, **aws_config["tags"]}
+    else:
+        tags = default_tags
+
+    job_submit_args["tags"] = tags
+    job_submit_args["propagateTags"] = (
+        True  # Propagate tags to ECS tasks and EC2 instances
+    )
+    print(f"Adding tags to batch job: {tags}")
 
     # Submit the job using the session client
     response = batch.submit_job(**job_submit_args)
